<template>
  <PageLayoutWithBg class="index-page-wrapper" :title="''" :need-auth="false">
    <template #left>
      <div class="menu-btn-wrapper menu-logo">
        <img :src="IconLogo" class="logo" />
      </div>
    </template>
    <div class="home-header">
      <div class="home-banner-wrapper">
        <nut-swiper :auto-play="3000">
          <nut-swiper-item v-for="(item, index) in list" :key="index">
            <img :src="item" class="banner-img" draggable="false" />
          </nut-swiper-item>
        </nut-swiper>
      </div>
    </div>
    <InfiniteLoading
      scrollViewClassName="common-infinite-scroll-list home-list"
      v-bind="infiniteLoadingProps"
    >
      <template #renderItem="{ item }">
        <div>TaskCard</div>
      </template>
    </InfiniteLoading>
  </PageLayoutWithBg>
</template>

<script setup lang="ts">
import { useUser, useInfiniteLoading } from '@/hooks';
import { useUserStore } from '@/stores/modules/user';
import { RectDown, Location2 } from '@nutui/icons-vue-taro';
import Taro from '@tarojs/taro';
import _ from 'lodash';
import IconLogo from '@/assets/home/icon-logo.png';
import IconLocaltion from '@/assets/task/icon-localtion.png';
import * as orderServices from '@life-payment/services/api/Order';
import { OrderInputType } from '@life-payment/constants';

const { locationCity } = useUser();

const userStore = useUserStore();

const queryState = reactive({});

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.FrontOrderListInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [{ property: 'lastShelfTime', order: OrderInputType.Desc }],
      },
    };

    return orderServices.getFrontOrderList(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['orderServices/getFrontOrderList', queryState],
  }
);

const list = ref([
  'https://storage.360buyimg.com/jdc-article/NutUItaro34.jpg',
  'https://storage.360buyimg.com/jdc-article/NutUItaro2.jpg',
  'https://storage.360buyimg.com/jdc-article/welcomenutui.jpg',
  'https://storage.360buyimg.com/jdc-article/fristfabu.jpg',
]);

const selectItem = ref();

function handleMenuSelectClose() {
  selectItem.value?.toggle?.();
}
</script>

<style lang="scss">
@import '@/styles/common.scss';

.index-page-wrapper {
  .menu-logo {
    padding: 0;

    .logo {
      width: 96px;
      height: 64px;
    }
  }

  .home-searchbar-wrapper {
    padding: 32px 0;
    display: flex;

    .searchbar-container {
      flex: 1;
      min-width: 0;
    }

    .city-btn {
      display: flex;
      align-items: center;
      padding-left: 36px;
      color: boleGetCssVar('text-color', 'primary');

      .city-btn-icon {
        width: 40px;
        height: 40px;
      }

      .city-btn-text {
        max-width: 200px;
        @include ellipsis;
        margin-left: 12px;
        font-size: 30px;
      }
    }
  }

  .home-banner-wrapper {
    .banner-img {
      width: 100%;
      height: 260px;
      object-fit: cover;
    }
  }

  .home-header {
    padding: 0 boleGetCssVar('size', 'body-padding-h');
  }
}

.home-list {
  @include infiniteLoadingInTabBarPage;
}
</style>
